PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/IPoint3.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Functions
IPoint3.hpp File Reference
`#include "Math/IPoint2.hpp"`

Go to the source code of this file.

## Data Structures
class | IVector_3
class | IPoint_3
struct | IBox_3

## Functions
std::ostream & | operator<< (std::ostream &os, const IVector_3 &V)
std::ostream & | operator<< (std::ostream &os, const IPoint_3 &P)
std::ostream & | operator<< (std::ostream &os, const IBox_3 &B)

## Function Documentation

## ◆ operator<<() [1/3]

std::ostream & operator<< | ( | std::ostream & | os,
|  | const IBox_3 & | B )
| inline

## ◆ operator<<() [2/3]

std::ostream & operator<< | ( | std::ostream & | os,
|  | const IPoint_3 & | P )
| inline

## ◆ operator<<() [3/3]

std::ostream & operator<< | ( | std::ostream & | os,
|  | const IVector_3 & | V )
| inline